{% lare_extends 'tests/page_1_content_1.html' 'Site1.Page1.Content1' 'django_lare/lare.html' %}
{% block inner_content %}<div id="inner_content">{{ inner_content_string }}</div>{% endblock inner_content %}
